@@ -10,14 +10,28 @@ describe Buff::ShellOut do
       expect(result).to be_a(described_class::Response)
     end
 
-    its(:stdout) { should be_a(String) }
-    its(:stderr) { should be_a(String) }
-    its(:exitstatus) { should be_a(Fixnum) }
-    its(:success?) { should be_true }
-    its(:error?) { should be_false }
+    it "has a string for stdout" do
+      expect(subject.stdout).to be_a(String)
+    end
+
+    it "has a string for stderr" do
+      expect(subject.stderr).to be_a(String)
+    end
+
+    it "has a fixnum for exitstatus" do
+      expect(subject.exitstatus).to be_a(Fixnum)
+    end
+
+    it "has a truth value for success?" do
+      expect(subject.success?).to eql(true)
+    end
+
+    it "has a false value for error?" do
+      expect(subject.error?).to eql(false)
+    end
 
     context "when on MRI" do
-      before { described_class.stub(jruby?: false) }
+      before { allow(described_class).to receive(:jruby?) { false } }
 
       it "delegates to #mri_out" do
         expect(described_class).to receive(:mri_out).with(command, {})
@@ -25,7 +39,7 @@ describe Buff::ShellOut do
       end
 
       context "when Process.waitpid2 returns an Integer instead of a Process::Status" do
-        before { Process.stub(:waitpid2).and_return([12345, 0]) }
+        before { allow(Process).to receive(:waitpid2) { [12345, 0] } }
 
         it "sets the exitstatus to the returned integer" do
           expect(result.exitstatus).to eql(0)
@@ -34,7 +48,7 @@ describe Buff::ShellOut do
     end
 
     context "when on JRuby" do
-      before { described_class.stub(jruby?: true) }
+      before { allow(described_class).to receive(:jruby?) { true } }
 
       it "delegates to #jruby_out" do
         expect(described_class).to receive(:jruby_out).with(command, {})
